function [x,p]=DGLfunc(Temp,xspan)
% Eingabewerte:
%                -Temp: Temperatur
%                -xspan: Lnge des Rohrreaktors als Vektor
% Ausgabewerte:
%                -x: Lngenvektor
%                -p: Matrix mit Partialdrcken (pro Spalte ein Gas)



%% Parameter Definition
%Temperatur und Gaskonstante
q.T=Temp; %[K]
q.R=8.3145; %[J/(mol*K)]

%Geschwindigkeitskonstante
q.k=1.955e6*exp(-(67130/(q.R*q.T)));

%Adsorptionskoeffizineten
q.k_co=8.23e-5*exp(70650/(q.R*q.T));
q.k_h2=6.12e-9*exp(82900/(q.R*q.T));
q.k_h2o=1.77e5*exp(-88680/(q.R*q.T));

%GGW-Konstante
q.k_eq=1.26e-2*exp(4639/q.T);

%% Randbedingungen
p0=[0.09 0.23 0.41 0.06]; %Anfangskonzentration bei x=0 [bar]

%Optionen fr ODE-Solver
options=odeset('RelTol',1e-12,... % Def.: 1e-3
               'AbsTol',1e-15,... % Def.: 1e-6                    
               'NormControl','off');

%% Aufruf ODE-Solver
[x,p]=ode15s(@odefunc,xspan,p0,options,q);

end

function dpdx=odefunc(~,p,q)

%Adsorption der Komponenten
Q=1+q.k_co*p(1)+q.k_h2*p(3)+ ((q.k_h2o*p(2)) / p(3));

%Reaktionsrate
r=(q.k/p(3)) * ( p(1)*p(2)- ( p(3)*p(4) )/q.k_eq  )* (1/(Q^2));

%DGL System
dpdx(1)=-r; %CO
dpdx(2)=-r; %H2O
dpdx(3)=r; %H2
dpdx(4)=r; %CO2

dpdx=dpdx'; %Rckgabe muss Zeilenvektor sein
end