function [pCO_end] = DGLfunc_end(v,flag)
% Eingabewerte:
%                -v: Optimierungsvariable
%                -flag: entscheidet, ob das Ergebnis geplottet wird
%                       true: plot
%                       fals: keine plot und lediglich Berechnung und
%                       Rckgabe des Partialdrucks pCO_end
% Ausgabewerte:
%                -pCO_end: Partialdruck des CO am Ende des PFTR

if flag~=true
x_dist=v(9)/8; %Lnge eines quidistanten Abschnitts

for i=1:8
    if i~=1
        p0=[p(end,1) p(end,2) p(end,3) p(end,4)]; %Anfangswerte werden berschrieben
    else
        p0=[0.09 0.23 0.41 0.06];
    end
    xspan=[0 x_dist]; %Lnge des 'partiellen Rohreaktors'
    T=v(i);
    [x p]=DGLfunc2(T,xspan,p0); %Aufruf der Funktion zur Rckgabe der Partialdrcke
end %for
pCO_end=p(end,1);
end

if flag==true %nur zum Plotten des 'richtigen' Ergebnisses
    plot_solution(v);
end %if

end

function plot_solution(v)

x_dist=v(9)/8; %Lnge eines quidistanten Abschnitts

for i=1:8
    if i~=1
        p0=[p(end,1) p(end,2) p(end,3) p(end,4)]; %Anfangswerte werden berschrieben
    else
        p0=[0.09 0.23 0.41 0.06];
    end %if
    xspan=[0 x_dist]; %Lnge des 'partiellen Rohreaktors'
    T=v(i);
    [x p]=DGLfunc2(T,xspan,p0); %Aufruf der Funktion zur Rckgabe der Partialdrcke
    
    %% ab hier beginnt der Plot
    y_Temp_max=max(v)+max(v)/10; %maximaler angezeigter Wert der Temperatur fr Plots
    y_Temp=min(v(v>min(v))); %zweitkleinster Wert (nach Lnge) ist die kleinste Temperatur
    y_Temp_min=y_Temp-y_Temp/10; %minimal angezeigter Wert der Temperatur fr Plots
    
%     if i==1 %Annahme im ersten Durchlauf ist der Partialdruck fr CO am hchsten
%         y_Druck_max=max(p(:,1))+max(p(:,1))/10; %maximaler angezeigter Wert des Drucks fr Plots
%     end %if
    
    
    
    if i==1 %Annahme im ersten Durchlauf ist der Partialdruck fr CO am hchsten
        y_Druck_max=max(max(p))+max(max(p))/10; %maximaler angezeigter Wert des Drucks fr Plots
    end %if
    
    
    fig2=figure(2);
    set(fig2,'Name','Verlauf der Partialdrcke und Temperaturprofil des PFTR'); %Name der figure wird gendert
    subplot(2,1,1)
    hold on;
    plot(x+(i-1)*x_dist,p); %Plot der Partialdrcke von CO
    plot(x(end)+(i-1)*x_dist,[0:max(p(:,1))/100:y_Druck_max],'r'); %Trennstriche fr einzelne Abschnitte
    xlim([0 v(9)]);
    ylim([0 y_Druck_max])
    xlabel('Lnge x in m');
    ylabel('Partialdruck in bar');
    legend('CO','H2O','H2','CO2');
    title('Partialdruckverlauf bei acht quidistanten Abschnitten');
    
    
    subplot(2,1,2)
    hold on;
    plot(x+(i-1)*x_dist,linspace(v(i),v(i),length(x)),'-'); %Plot der Temperaturen in acht Abschnitten
    plot(x(end)+(i-1)*x_dist,[y_Temp_min:max(v)/100:y_Temp_max],'r') %Trennstriche fr einzelne Abschnitte
    xlim([0 v(9)]);
    ylim([y_Temp_min y_Temp_max])
    xlabel('Lnge x in m');
    ylabel('Temperatur in K');
    title('Ermittelte Temperaturen in Reaktorabschnitten');
    
end %for


end
